@@ -482,7 +482,7 @@ static double emissionProbability;
 		  [InternalError raiseEvent:
 		    "Invalid combinedBondCount: %d \n", combinedBondCount];
 	      }
-	      if ([uniformRandom rFloat] < bondingProbability) {
+	      if ([prng getTossWithProb: bondingProbability]) {
 		bond = [neighborLink createBondToNeighbor: oppositeNeighbor];
 		[bond setLink1: self];
 		[bond setNeighbor1: neighbor];
@@ -551,7 +551,7 @@ static double emissionProbability;
   Hole *hole;
 
   if (!absorbedSubstrate) {
-    if ([uniformRandom rFloat] < absorptionProbability) {
+    if ([prng getTossWithProb: absorptionProbability]) {
       neighbor = [defaultNeighbor getRandom];
       neighborParticle = [self getAgentAtNeighbor: neighbor];
       if (neighborParticle == nil)
@@ -602,7 +602,7 @@ static double emissionProbability;
 
 -doEmission {
   if (absorbedSubstrate) 
-    if ([uniformRandom rFloat] < emissionProbability) 
+    if ([prng getTossWithProb: emissionProbability]) 
       [self attemptEmission];
 
   return self;
@@ -649,7 +649,8 @@ static double emissionProbability;
 
 -doDisintegration {
   if (!disintegrating)
-    disintegrating = ([uniformRandom rFloat] < disintegrationProbability);
+    disintegrating = 
+      [prng getTossWithProb: disintegrationProbability];
 
   return self;
 }
