@@ -7,7 +7,7 @@
 */
 
 
-#import "SCLRandomBit.h"
+#import "PRNG.h"
 #import "NeighborhoodProtocol.h"
 #import "AgentManager.h"
 #import "ParticleManager.h"
@@ -29,7 +29,7 @@ extern ParticleManager *catalystMgr;
 
 extern AgentManager *bondMgr;
 
-extern SCLRandomBit *sclRandomBit;
+extern PRNG * prng;
 
 extern BOOL useMooreNeighbor;
 extern unsigned modelTime;
