@@ -13,7 +13,9 @@
   id probeDisplay;
 
   unsigned worldTime;
-  unsigned pmmlcgState;
+  unsigned prngState;
+  unsigned prngCount;
+  Color backgroundColor;
 }
 
 +createBegin: (id) aZone;
@@ -25,9 +27,13 @@
 -(unsigned) setWorldTime: (unsigned) time;
 -(unsigned) getWorldTime;
 
--setPMMLCGState: (unsigned) newState;
--(unsigned) getPMMLCGState;
+-setPRNGstate: (unsigned) newState;
+-(unsigned) getPRNGstate;
+-setPRNGcount: (unsigned) newCount;
+-(unsigned) getPRNGcount;
 
+-setBackgroundColor: (Color) color;
+-(Color) getBackgroundColor;
 
 -dropWorld;
 -createWorldWithX: (int) xSize Y: (int) ySize;
