@@ -53,7 +53,10 @@
     [probeLibrary getProbeForVariable: "worldTime"
        inClass: [finalSelf class]]];
   [probeMap addProbe: 
-    [probeLibrary getProbeForVariable: "pmmlcgState"
+    [probeLibrary getProbeForVariable: "prngState"
+       inClass: [finalSelf class]]];
+  [probeMap addProbe: 
+    [probeLibrary getProbeForVariable: "prngCount"
        inClass: [finalSelf class]]];
 
   messageProbe = 
@@ -97,7 +100,12 @@
   [probeMap addProbe: messageProbe];
 
   messageProbe = 
-    [probeLibrary getProbeForMessage: "setPMMLCGState:"
+    [probeLibrary getProbeForMessage: "setPRNGstate:"
+      inClass: [self class]];
+  [messageProbe setHideResult: 1];
+  [probeMap addProbe: messageProbe];
+  messageProbe = 
+    [probeLibrary getProbeForMessage: "setPRNGcount:"
       inClass: [self class]];
   [messageProbe setHideResult: 1];
   [probeMap addProbe: messageProbe];
@@ -149,9 +157,22 @@
   return worldTime;
 }
 
+-setBackgroundColor: (Color) color {
+  backgroundColor = color;
+
+  return self;
+}
+
+-(Color) getBackgroundColor {
+  return backgroundColor;
+}
+
 -refreshDisplay{
   if (world != nil) { // Defensive...
-    [worldRaster erase];
+    //    [worldRaster erase];
+    [worldRaster fillRectangleX0: 0 Y0: 0
+      X1: ([world getSizeX] * 8) Y1: ([world getSizeY] * 8) 
+      Color: backgroundColor];
     [[bondMgr getAgentList] forEach: M(drawSelfOn:) : worldRaster];
     [worldDisplay display];
     [worldRaster drawSelf];
@@ -161,17 +182,30 @@
   return self;
 }
 
--setPMMLCGState: (unsigned) newState {
-  pmmlcgState = newState;
-  [sclRandomBit setPMMLCGState: pmmlcgState];
+-setPRNGstate: (unsigned) newState {
+  prngState = newState;
+  [prng setPRNGstate: prngState];
 
   return self;
 }
 
--(unsigned) getPMMLCGState {
-  pmmlcgState = [sclRandomBit getPMMLCGState]; // Defensive...
+-(unsigned) getPRNGstate {
+  prngState = [prng getPRNGstate]; // Defensive...
 
-  return pmmlcgState;
+  return prngState;
+}
+
+-setPRNGcount: (unsigned) newCount {
+  prngCount = newCount;
+  [prng setPRNGcount: prngCount];
+
+  return self;
+}
+
+-(unsigned) getPRNGcount {
+  prngCount = [prng getPRNGcount]; // Defensive...
+
+  return prngCount;
 }
 
 -update {
@@ -185,7 +219,8 @@
 
     [userCellEditor update];
 
-    [self getPMMLCGState];
+    [self getPRNGstate];
+    [self getPRNGcount];
     [self refreshDisplay];
   }
 
@@ -220,7 +255,8 @@
 
     [userCellEditor update];
 
-    [self getPMMLCGState];
+    [self getPRNGstate];
+    [self getPRNGcount];
     [self refreshDisplay];
   }
 
@@ -300,7 +336,7 @@
 
   worldRaster = [ZoomRaster create: [self getZone]];
   [worldRaster setColormap: colormap];
-  [worldRaster setZoomFactor: 4];
+  [worldRaster setZoomFactor: 3];
   [worldRaster setWidth: ([world getSizeX] * 8) 
                   Height: ([world getSizeY] * 8) ];
   [worldRaster setWindowTitle: "SCL World"];
@@ -653,8 +689,8 @@
       // This is going to get very slooooow if the 
       // material particle density in the world gets anywhere
       // near 1.0!!!
-      x = [uniformRandom rMax: xSize];
-      y = [uniformRandom rMax: ySize];
+      x = [prng getUniformWithRange: xSize];
+      y = [prng getUniformWithRange: ySize];
       particle = [world getObjectAtX: x Y: y];
       if ([particle isMemberOf: [Hole class]])
         holeFound = YES;
@@ -678,8 +714,8 @@
       // This is going to get very slooooow if the 
       // material particle density in the world gets anywhere
       // near 1.0!!!
-      x = [uniformRandom rMax: xSize];
-      y = [uniformRandom rMax: ySize];
+      x = [prng getUniformWithRange: xSize];
+      y = [prng getUniformWithRange: ySize];
       particle = [world getObjectAtX: x Y: y];
       if ([particle isMemberOf: [Hole class]])
         holeFound = YES;
@@ -701,15 +737,15 @@
 }
 
 -saveTo: (OutFile *) outFile {
-  [outFile putString: "World state...\n"];
+  [outFile putString: "# World state...\n"];
 
-  [sclRandomBit saveTo: outFile];
+  [prng saveTo: outFile];
 
-  [outFile putString: "worldTime...\n"];
+  [outFile putString: "# World Time...\n"];
   [outFile putInt: [worldManager getWorldTime]];  // Really need putUnsigned!
   [outFile putNewLine];
 
-  [outFile putString: "World Size...\n"];
+  [outFile putString: "# World Size...\n"];
   [outFile putInt: [world getSizeX]];
   [outFile putString: " "];
   [outFile putInt: [world getSizeY]];
@@ -729,19 +765,28 @@
 -loadFrom: (InFile *) inFile {
   int intParm;
   int xSize, ySize;
+  // char c;
 
   [self dropWorld];
 
-  [inFile skipLine]; // "World state...\n" 
+  [inFile skipLine]; // "# World state...\n" 
 
-  [sclRandomBit loadFrom: inFile];
+  //   [inFile getChar: &c];
+  // while (c != '\n') {
+  //   putchar(c);
+  //   [inFile getChar: &c];
+  //  }
+  // fflush(stdout);
+
+  [prng loadFrom: inFile];
+
+  [inFile skipLine]; // "# World Time...\n"
 
-  [inFile skipLine]; // "worldTime...\n"
   [inFile getInt: &intParm]; // Really need getUnsigned!
   [worldManager setWorldTime: intParm];
   [inFile skipLine];
 
-  [inFile skipLine]; // "World Size...\n"
+  [inFile skipLine]; // "# World Size...\n"
   [inFile getInt: &xSize];
   [inFile getInt: &ySize];
   [inFile skipLine];
